@@ -6,8 +6,8 @@ use std::{fmt, io};
 
 #[cfg(feature = "memory_usage")]
 use heapsize::{self, HeapSizeOf};
-use index::{ByteIndex, ByteOffset, ColumnIndex, LineIndex, LineOffset, RawIndex, RawOffset};
-use span::ByteSpan;
+use crate::index::{ByteIndex, ByteOffset, ColumnIndex, LineIndex, LineOffset, RawIndex, RawOffset};
+use crate::span::ByteSpan;
 
 #[derive(Clone, Debug, Eq, PartialEq, Ord, PartialOrd, Hash)]
 #[cfg_attr(feature = "serialization", derive(Deserialize, Serialize))]
@@ -175,9 +175,9 @@ pub struct FileMap<S = String> {
     lines: Vec<ByteOffset>,
 }
 
-impl FileMap {
+impl<S: AsRef<str> + From<String>> FileMap<S> {
     /// Read some source code from a file, loading it into a filemap
-    pub(crate) fn from_disk<P: Into<PathBuf>>(name: P, start: ByteIndex) -> io::Result<FileMap> {
+    pub(crate) fn from_disk<P: Into<PathBuf>>(name: P, start: ByteIndex) -> io::Result<FileMap<S>> {
         use std::fs::File;
         use std::io::Read;
 
@@ -186,7 +186,7 @@ impl FileMap {
         let mut src = String::new();
         file.read_to_string(&mut src)?;
 
-        Ok(FileMap::with_index(FileName::Real(name), src, start))
+        Ok(FileMap::with_index(FileName::Real(name), src.into(), start))
     }
 }
 
@@ -363,11 +363,13 @@ where
 
 #[cfg(test)]
 mod tests {
-    use std::sync::Arc;
-    use {CodeMap, FileMap, FileName};
 
     use super::*;
 
+    use std::sync::Arc;
+
+    use crate::CodeMap;
+
     struct TestData {
         filemap: Arc<FileMap>,
         lines: &'static [&'static str],
