@@ -35,12 +35,12 @@ mod filemap;
 mod index;
 mod span;
 
-pub use codemap::CodeMap;
-pub use filemap::{ByteIndexError, LineIndexError, LocationError, SpanError};
-pub use filemap::{FileMap, FileName};
-pub use index::{ByteIndex, ByteOffset};
-pub use index::{ColumnIndex, ColumnNumber, ColumnOffset};
-pub use index::{Index, Offset};
-pub use index::{LineIndex, LineNumber, LineOffset};
-pub use index::{RawIndex, RawOffset};
-pub use span::{ByteSpan, Span};
+pub use crate::codemap::CodeMap;
+pub use crate::filemap::{ByteIndexError, LineIndexError, LocationError, SpanError};
+pub use crate::filemap::{FileMap, FileName};
+pub use crate::index::{ByteIndex, ByteOffset};
+pub use crate::index::{ColumnIndex, ColumnNumber, ColumnOffset};
+pub use crate::index::{Index, Offset};
+pub use crate::index::{LineIndex, LineNumber, LineOffset};
+pub use crate::index::{RawIndex, RawOffset};
+pub use crate::span::{ByteSpan, Span};
